

#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	word工具集
#
###################################################################  

from	SpiritLong_word.word	import	open_docx,					\
					save_doc,					\
					save_docx,					\
					delete_paragraph,				\
					add_paragraphs,					\
					new_paragraph_data,				\
					new_run_data,					\
					add_blank_paragraphs,				\
					add_text_with_style,				\
					replace_text,					\
					append_text,					\
					find_paragraph,					\
					get_styles,					\
					table_remove_row,				\
					table_insert_row,				\
					set_cell_border,				\
					table_cell_fill,				\
					create_table,					\
					merge_cell,					\
					set_table_column_width_and_vertical_center


content	= '''<!--------------------------------------------------------------------
-              ____     _     _ __  __                 
-             / __/__  (_)___(_) /_/ /  ___  ___  ___ _
-            _\\ \\/ _ \\/ / __/ / __/ /__/ _ \\/ _ \\/ _ `/
-           /___/ .__/_/_/ /_/\\__/____/\\___/_//_/\\_, / 
-              /_/                              /___/  
- 
- Copyright (c) 2025 Chongqing Spiritlong Technology Co., Ltd.
- All rights reserved.
- @author	arthuryang
- @brief	主框架
--------------------------------------------------------------------->

<template>
	<!-- 登录 -->
	<div :style="[style_fullscreen, style_login]" v-show="login_enabled">
		<Login :title='login_title' :QR_code_string="QR_code_string" @login-button="login_button_handler"/>
	</div>

	<!-- 全局消息 -->
	<div :style="[style_fullscreen, style_viewport_message]" v-show="viewport_message_show">
		<p>message{{ store.viewport_message }}</p>
		<button type="button" @click="viewport_message_show	= false" style="height:30px;width:200px">隐藏全局消息</button>
	</div>

	<!-- 页面 -->
	<div :style="[style_PC]">
		<header :style="[style_PC_header]">
			<webframe_header :title="heading_text" :logo="logo_filename"/>
		</header>
		<aside :style="[style_PC_aside]">
			<webframe_sider :menu_items="menu_items" active_menu="1"/>
		
		</aside>
		<main :style="[style_PC_main]">
			<router-view></router-view>
		</main>
	</div>
</template>

<script setup>
// VUE基本
import	{ reactive }		from 'vue'
import	{ ref, onMounted }	from 'vue'
// store
import	{ storeToRefs }		from "pinia"
import	{ main_store }		from './main.js'
// webframe
import	{API}			from './webframe'
import	application_config	from './application_config'
// 框架组件
import	Login			from './components/login.vue'
import	webframe_header		from './components/webframe_header.vue'
import	webframe_sider		from './components/webframe_sider.vue'

const	store			= main_store();
const	{
	login_enabled, 
	viewport_message_show, 
}				= storeToRefs(store);

// 登录二维码
// TODO 随时间变化
const	QR_code_string		= ref('')
const base_URL		= application_config.base_URL;
const app_ID		= application_config.wechat_app_ID;
const websocket_code	= localStorage.getItem('websocket_code');
const redirect_URL	= encodeURIComponent(base_URL + '/API/authorize_scan?websocket_code=' + websocket_code + '&app_ID=' + app_ID);
QR_code_string.value	= base_URL + '/API/authorize_redirect?redirect_URL=' + redirect_URL + '&app_ID=' + app_ID;

let	login_title		= ref('登录提示')
let	heading_text		= ref(application_config.heading_text)
let	logo_filename		= ref(application_config.logo_filename)

// 登录处理
const	login_button_handler	= (username, password)=>{
	API('/login_password', {
		username,
		password
	}).then((data)=>{
		login_enabled.value	= false
		console.log('登录成功', data)
	})
}

// 菜单数据
// 菜单数据结构：
// [{
// 	name		: 菜单名称，必传
// 	icon		: 菜单图标，可选
// 	children	: 子菜单，可选
// 	icon_width	: 菜单图标宽度，可选
// 	icon_margin	: 菜单图标外边距，可选
// 	icon_color	: 菜单图标颜色，可选
// }]

const menu_items = reactive([
	{
		name: '任务',
		path: '/task'
	},
	{
		name: '事务',
		path: '/job'
	},
	{
		name: '用户管理',
		path: '/user'
	},
	{
		name: '权限管理',
		path: '/permission'
	},
	{
		name: '审批管理',
		path: '/approval'
	},
	{
		name: '日志管理',
		path: '/log'
	}
])

// ------------ style ---------------
// 注意：style应用时后面的属性会覆盖前面
const	style_login	= reactive({
	justifyContent	: 'center',
	alignItems	: 'center',
	zIndex		: '1',
});

const	style_viewport_message	= reactive({
	justifyContent	: 'center',
	alignItems	: 'center',
	zIndex		: '2',
});

const	style_fullscreen	= reactive({
	display		: 'flex',
	position	: 'absolute',
	left		: '0px',
	width		: '100%',
	top		: '0px',
	height		: '100%',
	backgroundColor	: 'white',
	zIndex		: '0',
});

const	style_PC	= reactive({
	width		: '100%',
	height		: '100vh',
	display		: 'grid',
	gridTemplateAreas	: `
		"header header"
		"aside main"
	`,
	gridTemplateRows	: 'auto 1fr',
	gridTemplateColumns	: 'auto 1fr',
	padding		: '0px',
	margin		: '0px',
	zIndex		: '0',
	overflow	: 'hidden'
});

const	style_PC_header	= reactive({
	width		: '100%',
	gridArea	: 'header'
});

// 新增 PC 布局的 aside 和 main 样式
const style_PC_aside = reactive({
	gridArea	: 'aside',
	height		: '100%',
	overflow	: 'hidden'
});

const style_PC_main = reactive({
	gridArea	: 'main',
	background	: '#f5f5f5',
	overflow	: 'auto',
	height		: '100%',
	boxSizing	: 'border-box',
});
</script>
'''


#!/usr/bin/python3
# coding=utf-8
##################################################################
#              ____     _     _ __  __                 
#             / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#            _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#           /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#              /_/                              /___/  
# 
# Copyright (c) 2025 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.
# @author	arthuryang
# @brief	生成webframe后端框架python版
##################################################################

import	os
import	webframe_python_routes_py
import	webframe_python_webframe_py
import	SpiritLong_utility

## 准备webframe_python基本框架
def generate_basic_frame(path, project_name='webframe'):
	# 创建基本目录
	os.makedirs(f"{path}/frontend", 	exist_ok=True)
	os.makedirs(f"{path}/application",	exist_ok=True)
	os.makedirs(f"{path}/config/",		exist_ok=True)
	os.makedirs(f"{path}/service/",		exist_ok=True)
	os.makedirs(f"{path}/script/",		exist_ok=True)
	os.makedirs(f"{path}/runtime/",		exist_ok=True)

	# 基本框架：routes.py	
	with open(f"{path}/routes.py", 'w') as f:
		f.write(webframe_python_routes_py.content)

	# 基本框架：webframe.py
	with open(f"{path}/webframe.py", 'w') as f:
		f.write(webframe_python_webframe_py.content)


# 脚本执行
if __name__ == '__main__':
	# # 给文件增加版权说明
	# SpiritLong_utility.copyright(__file__, author='arthuryang')
	
	generate_basic_frame('backend')


#!/usr/bin/python3
# coding=utf-8
##################################################################
#              ____     _     _ __  __                 
#             / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#            _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#           /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#              /_/                              /___/  
# 
# Copyright (c) 2025 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.
# @author	arthuryang
# @brief	VUE3项目框架实施
##################################################################

import	os
import	SpiritLong_utility
import	webframe_VUE3_src
import	webframe_VUE3_App_vue
import	webframe_VUE3_webframe_js

## 准备VUE3基本框架
def generate_basic_frame(path, project_name='webframe'):
	# 创建基本目录
	os.makedirs(f"{path}/public", 		exist_ok=True)
	os.makedirs(f"{path}/src/conponent", 	exist_ok=True)
	os.makedirs(f"{path}/src/view", 	exist_ok=True)
	os.makedirs(f"{path}/src/library", 	exist_ok=True)

	# ----------------------------------- src -----------------------------------
	with open(f'{path}/src/App.vue', 'w') as f:
		f.write(webframe_VUE3_App_vue.content)
	
	with open(f'{path}/src/main.js', 'w') as f:
		f.write(webframe_VUE3_src.content_main_js)

	with open(f'{path}/src/webframe.js', 'w') as f:
		f.write(webframe_VUE3_src.content_webframe_js)

	# ----------------------------------- package.json -----------------------------------
	with open(f'{path}/package.json', 'w') as f:
		f.write('''{
  "name"	: "vite-project",
  "private"	: true,
  "version"	: "0.0.0",
  "type"	: "module",
  "scripts"	: {
  	"dev"		: "vite --force --host",
  	"build"		: "vite build",
  	"preview"	: "vite preview"
  },
  "dependencies": {
  	"async-validator"		: "^4.2.5",
  	"axios"				: "^1.8.1",
  	"default-passive-events"	: "^2.0.0",
  	"lodash-es"			: "^4.17.21",
  	"nanoid"			: "^5.1.5",
  	"pinia"				: "^3.0.1",
  	"vconsole"			: "^3.15.1",
  	"vue"				: "^3.5.13",
  	"vue-qrcode"			: "^2.2.2",
  	"vue-router"			: "^4.5.0",
  	"ws"				: "^8.18.1"
  },
  "devDependencies": {
  	"@vitejs/plugin-vue"	: "^5.2.1",
  	"vite"			: "^6.2.3"
  }
}
''')
		
	# ----------------------------------- index.html -----------------------------------
	with open(f'{path}/index.html', 'w') as f:
		f.write('''
<!doctype html>
<html lang="en">
	<head>
		<meta charset="UTF-8" />
		<!-- 网页标题页LOGO -->
		<link rel="icon" type="image/svg+xml" href="/SpiritLong_logo_2024.svg" />
		<!-- 页面标题 -->
		<title>SpiritLong</title>
		<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	</head>
	<body style="padding: 0px;margin:0px;">
		<div id="app" ></div>
		<!-- 启动main.js -->
		<script type="module" src="/src/main.js"></script>
	</body>
</html>
''')
	# ----------------------------------- vite.config.js -----------------------------------
	with open(f'{path}/vite.config.js', 'w') as f:
		f.write('''import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'

// https://vite.dev/config/
export default defineConfig({
	plugins: [vue()],
	server	:{
		proxy	: {
			'/API'	: {
				// 服务器URL
				target		: 'https://develop02.spiritlong.com',
				// 更改源
				changeOrigin	: true,
				// 防止自签名https被VITE挡住
				secure		: false,
			}
		}
	},
})
''')


# 脚本执行
if __name__ == '__main__':
	# 给文件增加版权说明
	# SpiritLong_utility.copyright(__file__, author='arthuryang')

	generate_basic_frame('./frontend')





#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	其他工具集
#
###################################################################  

from	SpiritLong_utility.utility_string	import	is_float,		\
							UTF8_string_length,	\
							list_content_align_tab,	\
							SpiritLongJsonEncoder,	\
							object_to_json,		\
							json_to_object,		\
							json_to_bytes		

from	SpiritLong_utility.utility_math		import	decimal2

from	SpiritLong_utility.utility_files	import	walk_for_files

from	SpiritLong_utility.utility_datetime	import	datetime_string_parse,	\
							input_date
from	SpiritLong_utility.utility_copyright	import	copyright



#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	字符串相关工具，包括json
#
###################################################################  

import	datetime
import	re
import	os
import	json
import	decimal
import	unicodedata

## 判断一个字符串是不是浮点数
def is_float(s):
	try:
		float(s)
		# 浮点数
		return True
	except ValueError:
		pass

# 对UTF8字符串（中英文混合）计算显示长度，中文按两字符计算
def UTF8_string_length(s):
	length	= 0
	for c in s:
		# east_asian_width返回字符的类型，F和W都是占两个位置的（全角）
		length	+= 2 if unicodedata.east_asian_width(c) in 'FW' else 1
	return length

## 多行字符串按分隔字符串用tab对齐，适用于多行赋值/注释对齐
# 	list_data	多行数据，列表中每个元素是一行
#	seperators	分隔字符串列表，例如['=', '// ']
# 	TAB_length	TAB空格数
# 返回拼接好的多行字符串
def list_content_align_tab(list_data, seperators, TAB_length=8):
	# 把list_data按seperators分割成列表，每个元素对应一行是一个分割的各部分构成的子列表
	lines	= [[] for d in list_data]
	for seperator in seperators:
		# 字符串分割
		for i in range(len(list_data)):
			# 只分割一次
			parts	= list_data[i].split(seperator, maxsplit=1)
			# 分割是否成功都把第一个部分加进去
			lines[i].append(parts[0])
			# 分割成功则保留剩下的部分在list_data[i]，不成功则保留空字符串
			list_data[i]	= parts[1] if(len(parts)==2) else ''
	# 最后一个列要处理。lines的每个子列必定是一样长了
	lines	= [lines[i]+[list_data[i]] for i in range(len(lines))]
	
	# 计算每列的最大宽度
	column_lengths	= [max([UTF8_string_length(lines[i][j]) for i in range(len(lines))]) for j in range(len(lines[0]))]
	# 扩展到加上tab分隔后的列宽（按tab数）
	column_lengths	= [((int)(n/TAB_length)+1) for n in column_lengths]

	for i in range(len(lines)):
		# 逐行处理成输出的字符串
		line	= ''
		# 按分隔符数量来
		for j in range(len(seperators)):
			# 计算本行j列需要补的tab数
			column_align_tabs	= (int)((UTF8_string_length(lines[i][j]))/TAB_length)
			tabs	= column_lengths[j]-column_align_tabs
			line	+= lines[i][j]+'\t'*tabs
		# 注意要补上最后一个列
		lines[i]	= line+lines[i][len(seperators)]

	return lines

### JSON格式化日期和Decimal
class SpiritLongJsonEncoder(json.JSONEncoder):
	def default(self, obj):
		if isinstance(obj, datetime.datetime):
			return obj.strftime('%Y-%m-%d %H:%M:%S')
		elif isinstance(obj, datetime.date):
			return obj.strftime('%Y-%m-%d')
		elif isinstance(obj, decimal.Decimal):
			return str(obj).rstrip("0").rstrip(".")
		else:
			return json.JSONEncoder.default(self, obj) 
		
## 对象转json字符串
#	object_data	数据
#	default		默认值
# string
def object_to_json(object_data, default=""):
	try:
		return json.dumps(object_data, ensure_ascii=False, cls=SpiritLongJsonEncoder)
	except Exception as ex:
		return default
	
## json字符串转对象
#	json_string	数据
#	default		默认值
# object
def json_to_object(json_string, default={}):
	try:
		return json.loads(json_string, strict=False)
	except Exception as ex:
		return default

## json转为bytes
#	json_data	json对象
# b''
def json_to_bytes(json_data):
	return bytes(json_data, encoding='utf8')

# 调试/测试代码
if __name__ == '__main__':
	pass






#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	excel工具集
#
###################################################################  

import sys

from	SpiritLong_excel.excel	import		\
		cell_font,			\
		cell_fill,			\
		cell_border,			\
		open_xlsx,			\
		set_cell,			\
		get_records_with_title,		\
		get_records_with_parameters,	\
		get_records_with_table_fields,	\
		adjust_column_width,		\
		adjust_all_column_width,	\
		cell_code,			\
		records_to_sheet,		\
		records_to_excel,		\
		csv_save_as_xlsx,		\
		xls_save_as_xlsx,		\
		alignment_center,		\
		alignment_left,			\
		alignment_right,		\
		style_title